package com.ynet.life.search;

import java.sql.ResultSet;
import java.sql.SQLException;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

/* loaded from: com_ynet_life_search.jar:com/ynet/life/search/EXTBankNoIndexBuilder.class */
public class EXTBankNoIndexBuilder extends AbstractDBIndexBuilder {
    private static final String SQL_BANK_NO = "SELECT EBN_BANKNO, EBN_BANKTYPE, EBN_BANKNAME, nvl(EBN_STT,'0') STT, APR_SHOWMSG  FROM PUB_EXBANKNO, PUB_APPPAR WHERE EBN_BANKTYPE=APR_VALUE    AND APR_CODE='BANK_TYPE'   AND APR_LANGUAGE='zh_cn'";
    private static final String SQL_BANK_INDEX_FIELD = "SELECT EBN_BANKNO, EBN_BANKTYPE, EBN_BANKNAME, STT, APR_SHOWMSG";

    public EXTBankNoIndexBuilder(String indexFolderFile) {
        super(indexFolderFile, SQL_BANK_NO, SQL_BANK_INDEX_FIELD);
    }

    @Override // com.ynet.life.search.AbstractDBIndexBuilder
    protected Document getDocument(ResultSet rs) throws SQLException {
        String bankNo = rs.getString("EBN_BANKNO");
        String bankName = rs.getString("EBN_BANKNAME");
        String state = rs.getString("STT");
        String bankHeadName = rs.getString("APR_SHOWMSG");
        String bankType = rs.getString("EBN_BANKTYPE");
        String bankNo2 = bankNo == null ? "" : bankNo.trim();
        String fullContents = String.valueOf(bankHeadName) + bankName;
        Document doc = new Document();
        doc.add(new Field("keyWord", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("fullContents", fullContents, Field.Store.YES, Field.Index.ANALYZED));
        doc.add(new Field("bankType", bankType, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("unionBankNo", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("bankName", bankName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("state", state, Field.Store.YES, Field.Index.NOT_ANALYZED));
        return doc;
    }
}
